@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * object.h 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.rg>
  *
@@ -425,6 +425,23 @@ It should not be called by a program; call Object::EmitSignal instead.
 */
 	virtual bool OnSignal (SignalId Signal, Object *Child);
 
+/*!
+@param state: whether to bloc signals or not
+
+Blocks signals if state is true and unblocks if state is false.
+
+Since 0.4.2
+*/
+	void Lock (bool state = true);
+
+/*!
+
+@return true if signals are locked, false otherwise
+
+Since 0.4.2
+*/
+	bool IsLocked () {return m_Locked > 0;}
+
 /*!
 @param i: a C++ std::set<Object*> iterator.
 
@@ -573,11 +590,11 @@ private:
 	map<string, Object*> m_Children; //string is Id of object, so each object must have an Id
 	set<Object*> m_Links; //objects linked to this but outside of the hierarchy
 
-protected:
+private:
 /*!
 Set to true while loading to avoid signal propagation.
 */
-	bool m_IsLoading;
+	int m_Locked;
 };
 
 }
